/*--------------------------------------------------------------------
 * FICHERO:       Estilo.h
 * OBJETIVO:      Definir el objeto "Estilo"
 * IDENTIFICADOR: Est
 * COMPILADORES:  Turbo C++ y C68 4.03
 * AUTOR:         Pedro Reina
 * FECHA:         L.2.3.1998
 *------------------------------------------------------------------*/

/*--------------------------------------------------------------------
 * Funciones pblicas
 *
 *   Est_Crea()                Estilo.c
 *   Est_Destruye()            Estilo.c
 *   Est_Duplica()             Estilo.c
 *   Est_Fuente()              Estilo.h
 *   Est_Justificacion()       Estilo.h
 *   Est_MargenDerecho()       Estilo.h
 *   Est_MargenIzquierdo()     Estilo.h
 *   Est_MargenSangrado()      Estilo.h
 *   Est_Nombre()              Estilo.h
 *   Est_Numero()              Estilo.h
 *   Est_NumeroFuente()        Estilo.h
 *   Est_PonFuente()           Estilo.c
 *   Est_PonJustiicacion()     Estilo.h
 *   Est_PonMargenDerecho()    Estilo.h
 *   Est_PonMargenIzquierdo()  Estilo.h
 *   Est_PonMargenSangrado()   Estilo.h
 *   Est_PonNombre()           Estilo.c
 *   Est_PonNumero()           Estilo.h
 *   Est_PonNumeroFuente()     Estilo.h
 *   Est_PonTamano()           Estilo.h
 *   Est_PonTipoFuente()       Estilo.h
 *   Est_Tamano()              Estilo.h
 *   Est_TipoFuente()          Estilo.h
 *------------------------------------------------------------------*/

#ifndef _ESTILO_
#define _ESTILO_

/*--------------------------------------------------------------------
 * Ficheros de cabecera
 *------------------------------------------------------------------*/

#include <Olimpo.h>      /* Cadena */

/*--------------------------------------------------------------------
 * Definicin de macros constantes
 *------------------------------------------------------------------*/

#define EST_FUENTE_NIL    0
#define EST_FUENTE_ROMAN  1
#define EST_FUENTE_SWISS  2
#define EST_FUENTE_MODERN 3
#define EST_FUENTE_SCRIPT 4
#define EST_FUENTE_DECOR  5
#define EST_FUENTE_TECH   6

#define EST_JUST_IZQUIERDA 0
#define EST_JUST_DERECHA   1
#define EST_JUST_CENTRAL   2
#define EST_JUST_COMPLETA  3

/*--------------------------------------------------------------------
 * Definicin del tipo estilo
 *------------------------------------------------------------------*/

typedef struct {
               octeto   Numero;           /* Nmero asignado */
               cadena   Nombre;           /* Nombre del estilo */
               octeto   TipoFuente;       /* Tipo general de la fuente */
               octeto   NumeroFuente;     /* Nmero asignado a la fuente */
               cadena   Fuente;           /* Nombre de la fuente */
               octeto   Tamano;           /* Tamao de la fuente en puntos */
               octeto   Justificacion;    /* Izq, Dcha, Centro o Completa */
               contador MargenIzquierdo;  /* En milmetros */
               contador MargenDerecho;    /* En milmetros */
               contador MargenSangrado;   /* En milmetros desde el m. izq */
               } Est_st, *estilo;

/*--------------------------------------------------------------------
 * Variables globales
 *------------------------------------------------------------------*/

   /* Ninguna */

/*--------------------------------------------------------------------
 * Declaracin de funciones
 *------------------------------------------------------------------*/

estilo Est_Crea();
void   Est_Destruye();
estilo Est_Duplica();
cadena Est_PonFuente();
cadena Est_PonNombre();

/*--------------------------------------------------------------------
 * Definicin de macros funciones
 *------------------------------------------------------------------*/

/*--------------------------------------------------------------------
 * MACRO:    Est_Numero()
 * OBJETIVO: Decir el nmero de un estilo
 * ENTRADAS: El estilo
 * SALIDAS:  Un octeto que indica el nmero
 * EJEMPLO:  Est_Numero ( Estilo )
 *------------------------------------------------------------------*/
#define Est_Numero(e)  ((e)->Numero)

/*--------------------------------------------------------------------
 * MACRO:    Est_PonNumero()
 * OBJETIVO: Poner el nmero a un estilo
 * ENTRADAS: El estilo y el nmero
 * SALIDAS:  Un octeto que indica el nmero
 * EJEMPLO:  Est_PonNumero ( Estilo, 1 )
 *------------------------------------------------------------------*/
#define Est_PonNumero(e,n)  ((e)->Numero=(n))

/*--------------------------------------------------------------------
 * MACRO:    Est_Nombre()
 * OBJETIVO: Decir el nombre de un estilo
 * ENTRADAS: El estilo
 * SALIDAS:  La cadena del nombre
 * EJEMPLO:  Est_Nombre ( Estilo )
 *------------------------------------------------------------------*/
#define Est_Nombre(e)  ((e)->Nombre)

/*--------------------------------------------------------------------
 * MACRO:    Est_TipoFuente()
 * OBJETIVO: Decir el tipo de fuente de un estilo
 * ENTRADAS: El estilo
 * SALIDAS:  El tipo de fuente
 * EJEMPLO:  Est_TipoFuente ( Estilo )
 *------------------------------------------------------------------*/
#define Est_TipoFuente(e)  ((e)->TipoFuente)

/*--------------------------------------------------------------------
 * MACRO:    Est_PonTipoFuente()
 * OBJETIVO: Poner el tipo de fuente a un estilo
 * ENTRADAS: El estilo y el tipo de fuente
 * SALIDAS:  El tipo de fuente
 * EJEMPLO:  Est_PonTipoFuente ( Estilo, EST_FUENTE_ROMAN )
 *------------------------------------------------------------------*/
#define Est_PonTipoFuente(e,t)  ((e)->TipoFuente=(t))

/*--------------------------------------------------------------------
 * MACRO:    Est_NumeroFuente()
 * OBJETIVO: Decir el nmero de fuente de un estilo
 * ENTRADAS: El estilo
 * SALIDAS:  El nmero de fuente
 * EJEMPLO:  Est_NumeroFuente ( Estilo )
 *------------------------------------------------------------------*/
#define Est_NumeroFuente(e)  ((e)->NumeroFuente)

/*--------------------------------------------------------------------
 * MACRO:    Est_PonNumeroFuente()
 * OBJETIVO: Poner el nmero de fuente a un estilo
 * ENTRADAS: El estilo y el nmero de fuente
 * SALIDAS:  El nmero de fuente
 * EJEMPLO:  Est_PonNumeroFuente ( Estilo, 2 )
 *------------------------------------------------------------------*/
#define Est_PonNumeroFuente(e,n)  ((e)->NumeroFuente=(n))

/*--------------------------------------------------------------------
 * MACRO:    Est_Fuente()
 * OBJETIVO: Decir la fuente de un estilo
 * ENTRADAS: El estilo
 * SALIDAS:  La cadena de la fuente
 * EJEMPLO:  Est_Fuente ( Estilo )
 *------------------------------------------------------------------*/
#define Est_Fuente(e)  ((e)->Fuente)

/*--------------------------------------------------------------------
 * MACRO:    Est_Tamano()
 * OBJETIVO: Decir el tamao de la fuente de un estilo
 * ENTRADAS: El estilo
 * SALIDAS:  Un octeto que indica el tamao de la fuente
 * EJEMPLO:  Est_Tamano ( Estilo )
 *------------------------------------------------------------------*/
#define Est_Tamano(e)  ((e)->Tamano)

/*--------------------------------------------------------------------
 * MACRO:    Est_PonTamano()
 * OBJETIVO: Poner el tamao de la fuente a un estilo
 * ENTRADAS: El estilo y el tamao de la fuente
 * SALIDAS:  Un octeto que indica el tamao de la fuente
 * EJEMPLO:  Est_PonTamano ( Estilo, 24 )
 *------------------------------------------------------------------*/
#define Est_PonTamano(e,t)  ((e)->Tamano=(t))

/*--------------------------------------------------------------------
 * MACRO:    Est_Justificacion()
 * OBJETIVO: Decir la justificacin de un estilo
 * ENTRADAS: El estilo
 * SALIDAS:  La justificacin
 * EJEMPLO:  Est_Justificacion ( Estilo )
 *------------------------------------------------------------------*/
#define Est_Justificacion(e)  ((e)->Justificacion)

/*--------------------------------------------------------------------
 * MACRO:    Est_PonJustificacion()
 * OBJETIVO: Poner la justificacin a un estilo
 * ENTRADAS: El estilo y la justificacin
 * SALIDAS:  La justificacin
 * EJEMPLO:  Est_PonJustificacion ( Estilo, EST_JUST_COMPLETA )
 *------------------------------------------------------------------*/
#define Est_PonJustificacion(e,j)  ((e)->Justificacion=(j))

/*--------------------------------------------------------------------
 * MACRO:    Est_MargenIzquierdo()
 * OBJETIVO: Decir el margen izquierdo de un estilo
 * ENTRADAS: El estilo
 * SALIDAS:  Un contador que indica el margen izquierdo
 * EJEMPLO:  Est_MargenIzquierdo ( Estilo )
 *------------------------------------------------------------------*/
#define Est_MargenIzquierdo(e)  ((e)->MargenIzquierdo)

/*--------------------------------------------------------------------
 * MACRO:    Est_PonMargenIzquierdo()
 * OBJETIVO: Poner el margen izquierdo a un estilo
 * ENTRADAS: El estilo y el margen izquierdo
 * SALIDAS:  Un contador que indica el margen izquierdo
 * EJEMPLO:  Est_PonMargenIzquierdo ( Estilo, 10 )
 *------------------------------------------------------------------*/
#define Est_PonMargenIzquierdo(e,m)  ((e)->MargenIzquierdo=(m))

/*--------------------------------------------------------------------
 * MACRO:    Est_MargenDerecho()
 * OBJETIVO: Decir el margen derecho de un estilo
 * ENTRADAS: El estilo
 * SALIDAS:  Un contador que indica el margen derecho
 * EJEMPLO:  Est_MargenDerecho ( Estilo )
 *------------------------------------------------------------------*/
#define Est_MargenDerecho(e)  ((e)->MargenDerecho)

/*--------------------------------------------------------------------
 * MACRO:    Est_PonMargenDerecho()
 * OBJETIVO: Poner el margen derecho a un estilo
 * ENTRADAS: El estilo y el margen derecho
 * SALIDAS:  Un contador que indica el margen derecho
 * EJEMPLO:  Est_PonMargenDerecho ( Estilo, 10 )
 *------------------------------------------------------------------*/
#define Est_PonMargenDerecho(e,m)  ((e)->MargenDerecho=(m))

/*--------------------------------------------------------------------
 * MACRO:    Est_MargenSangrado()
 * OBJETIVO: Decir el margen de sangrado de un estilo
 * ENTRADAS: El estilo
 * SALIDAS:  Un contador que indica el margen de sangrado
 * EJEMPLO:  Est_MargenSangrado ( Estilo )
 *------------------------------------------------------------------*/
#define Est_MargenSangrado(e)  ((e)->MargenSangrado)

/*--------------------------------------------------------------------
 * MACRO:    Est_PonMargenSangrado()
 * OBJETIVO: Poner el margen de sangrado a un estilo
 * ENTRADAS: El estilo y el margen de sangrado
 * SALIDAS:  Un contador que indica el margen de sangrado
 * EJEMPLO:  Est_PonMargenSangrado ( Estilo, 10 )
 *------------------------------------------------------------------*/
#define Est_PonMargenSangrado(e,m)  ((e)->MargenSangrado=(m))

#endif /* _ESTILO_ */